==> uimaj-3.3.0-source-release.zip: uimaj-3.3.0/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/RsFeat.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.uima.analysis_engine.impl;

/**
 * Represents the languages associated with one explicit type:feature in a result spec
 */
public class RsFeat {
  final String shortFeatName; // these are canonical strings, can be compared ==
  RsLangs languages = null;

  RsFeat(String shortName, String[] languages) {
    this.shortFeatName = shortName;
    this.languages = RsLangs.createOrNull(languages);
  }

  RsFeat(String shortName, RsLangs languages) {
    this.shortFeatName = shortName;
    if (null != languages) {
      languages.setShared();
    }
    this.languages = languages;
  }

  RsFeat(RsFeat original) {
    shortFeatName = original.shortFeatName;
    if (null != original.languages) {
      original.languages.setShared();
    }
    languages = original.languages;
  }

  boolean subsumes(String language) {
    return RsLangs.subsumes(languages, language);
  }
}

==> uimaj-3.6.1-source-release.zip: uimaj-3.6.1/uimaj-core/src/main/java/org/apache/uima/analysis_engine/impl/RsFeat.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.uima.analysis_engine.impl;

/**
 * Represents the languages associated with one explicit type:feature in a result spec
 */
public class RsFeat {
  final String shortFeatName; // these are canonical strings, can be compared ==
  RsLangs languages = null;

  RsFeat(String shortName, String[] languages) {
    shortFeatName = shortName;
    this.languages = RsLangs.createOrNull(languages);
  }

  RsFeat(String shortName, RsLangs languages) {
    shortFeatName = shortName;
    if (null != languages) {
      languages.setShared();
    }
    this.languages = languages;
  }

  RsFeat(RsFeat original) {
    shortFeatName = original.shortFeatName;
    if (null != original.languages) {
      original.languages.setShared();
    }
    languages = original.languages;
  }

  boolean subsumes(String language) {
    return RsLangs.subsumes(languages, language);
  }
}
